$(document).ready(function(){
    var i = 1;
    $('img.graph').each(function(){
        var data = $.parseJSON(htmlspecialchars_decode($(this).attr('data-graph'), 0));
        var graph_id = 'graph' + i;

        $(this).replaceWith('<div id="'+graph_id+'" style="width: 100%;"></div>');
        var graph = $('#'+graph_id);
        graph_view($(this).data('title'), $(this).data('subtitle'), $(this).data('text'), $(this).data('suffix'), $(this).data('type'), data, graph);
        i++;
    });
});

function graph_view(title, subtitle, text, suffix, type, data, graph) {
    var obj = {};
    if (!title)    title    = '';
    if (!subtitle) subtitle = '';
    if (!text)     text     = '';
    if (!suffix)   suffix   = '';

    if (type == 1) {
        var categories = data['category'];
        var series = data['series'];

        for (var i in series)
        {
            for (var j in series[i]['data'])
            {
                series[i]['data'][j] = parseInt(series[i]['data'][j]);
            }
        }

        obj = {
            chart: {
                height: 600,
                type: 'line'
            },
            title: {
                text: title,
                x: -20
            },
            subtitle: {
                text: subtitle,
                x: -20
            },
            xAxis: {
                categories: categories
            },
            yAxis: {
                title: {
                    text: text
                },
                plotLines: [{
                    value: 0,
                    width: 1,
                    color: '#808080'
                }]
            },
            tooltip: {
                valueSuffix: suffix
            },
            legend: {
                layout: 'horizontal',
                align: 'center',
                borderWidth: 0,
                itemStyle: {
                    paddingBottom: '10px',
                    width: 195
                }
            },
            credits: {
                enabled: false
            },
            series: series
        };
    } else if ( type == 2 ) {
        var start = parseInt(data['start']);
        var series = data['series'];

        for (var i in series)
        {
            for (var j in series[i]['data'])
            {
                series[i]['data'][j] = parseInt(series[i]['data'][j]);
            }
        }

        obj = {
            chart: {
                type: 'area'
            },
            title: {
                text: title
            },
            subtitle: {
                text: subtitle
            },
            yAxis: {
                title: {
                    text: text
                }
            },
            tooltip: {
                pointFormat: '{series.name}: {point.y}' + suffix
            },
            plotOptions: {
                area: {
                    pointStart: start,
                    marker: {
                        enabled: false,
                        symbol: 'circle',
                        radius: 2,
                        states: {
                            hover: {
                                enabled: true
                            }
                        }
                    }
                }
            },
            credits: {
                enabled: false
            },
            series: series
        };
    } else if ( type == 3 ) {
        var colors = Highcharts.getOptions().colors;
        var categories = data['category'];
        var value = data['value'];
        data = [];

        for (var i = 0; i < value.length; i++)
        {
            data.push({
                y: parseInt(value[i]),
                color: colors[i % 10]
            });
        }

        obj = {
            chart: {
                type: 'column'
            },
            title: {
                text: title
            },
            subtitle: {
                text: subtitle
            },
            legend: {
                enabled: false
            },
            xAxis: {
                categories: categories
            },
            yAxis: {
                title: {
                    text: text
                }
            },
            plotOptions: {
                column: {
                    dataLabels: {
                        enabled: true,
                        color: colors[0],
                        style: {
                            fontWeight: 'bold'
                        },
                        formatter: function() {
                            return this.y + suffix;
                        }
                    }
                }
            },
            tooltip: {
                formatter: function() {
                    var point = this.point,
                        s = this.x +':<b>'+ this.y + suffix + '</b><br/>';
                    return s;
                }
            },
            credits: {
                enabled: false
            },
            series: [{
                name: title,
                data: data,
                color: 'white'
            }]
        };
    } else if ( type == 4 ) {

        var category = data['category'];
        var value = data['value'];
        data = [];

        for (var i = 0; i < category.length; i++)
        {
            data.push([category[i],  parseInt(value[i])]);
        }

        obj = {
            chart: {
                plotBackgroundColor: null,
                plotBorderWidth: null,
                plotShadow: false
            },
            title: {
                text: title
            },
            subtitle: {
                text: subtitle
            },
            tooltip: {
                pointFormat: '{series.name}: <b>{point.percentage:.1f}%</b>'
            },
            plotOptions: {
                pie: {
                    allowPointSelect: true,
                    cursor: 'pointer',
                    dataLabels: {
                        enabled: true,
                        color: '#000000',
                        connectorColor: '#000000',
                        format: '<b>{point.name}</b>: {point.percentage:.1f} %'
                    }
                }
            },
            credits: {
                enabled: false
            },
            series: [{
                type: 'pie',
                name: suffix,
                data: data
            }]
        };
    }

    graph.highcharts(obj);
}

function htmlspecialchars_decode (string, quote_style) {
    var optTemp = 0,
        i = 0,
        noquotes = false;
    if (typeof quote_style === 'undefined') {
        quote_style = 2;
    }
    string = string.toString().replace(/&lt;/g, '<').replace(/&gt;/g, '>');
    var OPTS = {
        'ENT_NOQUOTES': 0,
        'ENT_HTML_QUOTE_SINGLE': 1,
        'ENT_HTML_QUOTE_DOUBLE': 2,
        'ENT_COMPAT': 2,
        'ENT_QUOTES': 3,
        'ENT_IGNORE': 4
    };
    if (quote_style === 0) {
        noquotes = true;
    }
    if (typeof quote_style !== 'number') {
        quote_style = [].concat(quote_style);
        for (i = 0; i < quote_style.length; i++) {
            if (OPTS[quote_style[i]] === 0) {
                noquotes = true;
            } else if (OPTS[quote_style[i]]) {
                optTemp = optTemp | OPTS[quote_style[i]];
            }
        }
        quote_style = optTemp;
    }
    if (quote_style & OPTS.ENT_HTML_QUOTE_SINGLE) {
        string = string.replace(/&#0*39;/g, "'");
    }
    if (!noquotes) {
        string = string.replace(/&quot;/g, '"');
    }

    string = string.replace(/&amp;/g, '&');

    return string;
}